package com.expertandroid.plugin;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.CommonDataKeys;
import com.intellij.openapi.application.ApplicationManager;
import com.intellij.openapi.command.WriteCommandAction;
import com.intellij.openapi.editor.Document;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.editor.SelectionModel;
import com.intellij.openapi.project.Project;

import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

/**
 * Created by murat on 2/10/16.
 */
public class EditorAction extends AnAction {
    @Override
    public void actionPerformed(AnActionEvent anActionEvent) {
        //Get all the required data from data keys
        final Editor editor = anActionEvent.getRequiredData(CommonDataKeys.EDITOR);
        final Project project = anActionEvent.getRequiredData(CommonDataKeys.PROJECT);
        //Access document, caret, and selection
        final Document document = editor.getDocument();
        final SelectionModel selectionModel = editor.getSelectionModel();
        final int start = selectionModel.getSelectionStart();
        final int end = selectionModel.getSelectionEnd();

        Runnable runnable = new Runnable() {
            @Override
            public void run() {
                String unicodeText=convertTr(selectionModel.getSelectedText());
                document.replaceString(start, end, unicodeText);
            }
        };
        //Making the replacement
        WriteCommandAction.runWriteCommandAction(project, runnable);
        selectionModel.removeSelection();

    }


    @Override
    public void update(AnActionEvent anActionEvent){
        //Get required data keys
        final Project project = anActionEvent.getData(CommonDataKeys.PROJECT);
        final Editor editor = anActionEvent.getData(CommonDataKeys.EDITOR);
        //Set visibility only in case of existing project and editor

        anActionEvent.getPresentation().setVisible((project != null && editor != null
                && editor.getSelectionModel().hasSelection()));
    }

    private String convertTr(String nativeText) {
        Map charMap = new HashMap<>();
        charMap.put("s", "\\\\u00e7");
        charMap.put("ç", "\\\\u00e7");
        charMap.put("Ç", "\\\\u00c7");
        charMap.put("ğ", "\\\\u011f");
        charMap.put("Ğ", "\\\\u011e");
        charMap.put("ş", "\\\\u015f");
        charMap.put("Ş", "\\\\u015e");
        charMap.put("ı", "\\\\u0131");
        charMap.put("İ", "\\\\u0130");
        charMap.put("ö", "\\\\u00f6");
        charMap.put("Ö", "\\\\u00d6");
        charMap.put("ü", "\\\\u00fc");
        charMap.put("Ü", "\\\\u00dc");
        String asciiText = "";
        if (nativeText != null) {
            asciiText = new String(nativeText);
            Set keySet = charMap.keySet();
            Iterator it = keySet.iterator();
            while (it.hasNext()) {
                String nativeChar = (String) it.next();
                String asciiChar = (String) charMap.get(nativeChar);
                asciiText = asciiText.replaceAll(nativeChar, asciiChar);
            }
        }
        return asciiText;
    }
}
